.. rst-class:: detail

ReadDigital
======================

.. currentmodule:: compas_rrc

.. autoclass:: ReadDigital

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~ReadDigital.__init__
        ~ReadDigital.from_msg
        ~ReadDigital.parse_feedback
    
    